==> erpmc-0.1.7.tar.gz: lib/account_management/account/model/filter.dart <==
part of '../../../account_management.dart';

class AccountFilter extends NameFilter<int, AccountModel> {
  final InWhere<int>? branchIds;
  final InWhere<int>? typeIds;
  final InWhere<int>? levelIds;
  final InWhere<int>? groupIds;
  final InWhere<int>? upIds;

  final InWhere<int>? userIds;
  const AccountFilter({
    super.ids,
    super.status,
    super.text,
    this.branchIds,
    this.typeIds,
    this.levelIds,
    this.groupIds,
    this.upIds,
    this.userIds,
  });

  @override
  Map<String, dynamic> toMap() => {
        "branchIds": branchIds?.toMap(),
        "typeIds": typeIds?.toMap(),
        "levelIds": levelIds?.toMap(),
        "groupIds": groupIds?.toMap(),
        "upIds": upIds?.toMap(),
        "userIds": userIds?.toMap(),
      };

  @override
  bool check(AccountModel element) =>
      super.check(element) &&
      (branchIds?.check(element.branchId) ?? true) &&
      (typeIds?.check(element.typeId) ?? true) &&
      (levelIds?.check(element.levelId) ?? true) &&
      (groupIds?.check(element.groupId) ?? true) &&
      (upIds?.check(element.upId) ?? true) &&
      (userIds?.check(element.userId) ?? true);

  @override
  AccountFilter copyWith({
    InWhere<int>? ids,
    InWhere<bool>? status,
    LikeWhere? text,
    InWhere<int>? branchIds,
    InWhere<int>? typeIds,
    InWhere<int>? levelIds,
    InWhere<int>? groupIds,
    InWhere<int>? upIds,
    InWhere<int>? userIds,
  }) =>
      AccountFilter(
        ids: ids ?? this.ids,
        status: status ?? this.status,
        text: text ?? this.text,
        branchIds: branchIds ?? this.branchIds,
        typeIds: typeIds ?? this.typeIds,
        levelIds: levelIds ?? this.levelIds,
        groupIds: groupIds ?? this.groupIds,
        upIds: upIds ?? this.upIds,
        userIds: userIds ?? this.userIds,
      );
}

==> erpmc-1.0.3.tar.gz: lib/account_management/account/model/filter.dart <==
part of '../../../account_management.dart';

class AccountFilter extends NameFilter<AccountModel> {
  final InWhere<int>? branchIds;
  final InWhere<int>? typeIds;
  final InWhere<int>? levelIds;
  final InWhere<int>? groupIds;
  final InWhere<int>? upIds;

  final InWhere<int>? userIds;
  const AccountFilter({
    super.ids,
    super.status,
    super.text,
    this.branchIds,
    this.typeIds,
    this.levelIds,
    this.groupIds,
    this.upIds,
    this.userIds,
  });

  @override
  Map<String, dynamic> toMap() => {
        "branchIds": branchIds?.toMap(),
        "typeIds": typeIds?.toMap(),
        "levelIds": levelIds?.toMap(),
        "groupIds": groupIds?.toMap(),
        "upIds": upIds?.toMap(),
        "userIds": userIds?.toMap(),
      };

  @override
  bool check(AccountModel element) =>
      super.check(element) &&
      (branchIds?.check(element.branchId) ?? true) &&
      (typeIds?.check(element.typeId) ?? true) &&
      (levelIds?.check(element.levelId) ?? true) &&
      (groupIds?.check(element.groupId) ?? true) &&
      (ids?.checkStartWith(element.upId) ?? true) &&
      (upIds?.checkStartWith(element.upId) ?? true) &&
      (userIds?.check(element.userId) ?? true);

  @override
  AccountFilter copyWith({
    InWhere<int>? ids,
    InWhere<bool>? status,
    LikeWhere? text,
    InWhere<int>? branchIds,
    InWhere<int>? typeIds,
    InWhere<int>? levelIds,
    InWhere<int>? groupIds,
    InWhere<int>? upIds,
    InWhere<int>? userIds,
  }) =>
      AccountFilter(
        ids: ids ?? this.ids,
        status: status ?? this.status,
        text: text ?? this.text,
        branchIds: branchIds ?? this.branchIds,
        typeIds: typeIds ?? this.typeIds,
        levelIds: levelIds ?? this.levelIds,
        groupIds: groupIds ?? this.groupIds,
        upIds: upIds ?? this.upIds,
        userIds: userIds ?? this.userIds,
      );
}
